@@ -71,7 +71,9 @@ inMemory <- function(x) {
 
 hasValues <- function(x) {
 	if (class(x) == 'BasicRaster') { return(FALSE) }
-	if (inherits(x) == 'RasterStack') { return(TRUE) }
+	if (inherits(x, 'RasterStack')) { 
+		if (nlayers(x) > 0) return(TRUE) else return(FALSE)
+	}
 	if ( fromDisk(x)  | inMemory(x) ) {
 		return(TRUE)
 	} else {
