@@ -35,10 +35,10 @@
 	cat('ref. system :', refsystem, "\n", file = thefile)
 	cat('ref. units  :', refunits, "\n", file = thefile)
 	cat('unit dist.  : 1.0000000', "\n", file = thefile)
-	cat('min. X      :', xmin(raster), "\n", file = thefile)
-	cat('max. X      :', xmax(raster), "\n", file = thefile)
-	cat('min. Y      :', ymin(raster), "\n", file = thefile)
-	cat('max. Y      :', ymax(raster), "\n", file = thefile)
+	cat('min. X      :', as.character(xmin(raster)), "\n", file = thefile)
+	cat('max. X      :', as.character(xmax(raster)), "\n", file = thefile)
+	cat('min. Y      :', as.character(ymin(raster)), "\n", file = thefile)
+	cat('max. Y      :', as.character(ymax(raster)), "\n", file = thefile)
 	cat("pos'n error : unknown\n", file = thefile)
 	cat('resolution  :', xres(raster), "\n", file = thefile)
 	cat('min. value  :', minValue(raster), "\n", file = thefile)
